.TH STF 1.01 "28 July 200"
.SH NAME
stf \- Simple Text Format
.SH SYNOPSIS
\fBstf\fP [--help] [-v] [-h \fI<headerfile>\fP] [-f \fI<footerfile>\fP] [-i] [-t] [-u] [-l] [-s] \fIfilename\fP
.SH DESCRIPTION
\fISimple Text Format (STF)\fP is a simple set of rules for parsing plain text files to create html output.
The html output can be modified by creating a stf.conf file. Default header and footer files can be included
to create a consistant lay-out in the output.

Also source files can be included where the < and > characters in the source will be transformed into html
entities (e.g. &lt; and &gt;)

Stf uses 6 "content types" which have the following rules tight to them:
(Note that STF looks at the first character of a line to determine the content type.
STF considers a character other than [tab][newline][-][+] as a 'normal character'.)

.TP
1 Document title
Starts with the first line of the document ends when a blank line is encountered.
.TP
2 Sub title
Starts when the first character of a line is a normal character and is preceeded by more than one blank line,
ends when a blank line is encountered.
.TP
3 Text paragraph
Starts when the first character of a line is a normal character and is preceeded by exactly one blank line,
ends when a blank line is encountered
.TP
4 Code paragraph
Starts when the first character of a line is a [tab] character, ends when a blank line is encountered
.TP
5 List items
Starts when the first character of a line is a [-] character and is preceeded by one or more blank lines,
ends when a blank line is encountered
.TP
6 Include file
Starts when the first character of a line is a [+] character and is preceeded by one or more blank lines,
ends immediately

.SH ADDITIONAL INFORMATION
When a content type is started, while one of the above rules apply for a line, STF will continue with that content
type untill a blank line is encountered. This means that the first character of a line looses its STF meaning inside
a content block.

The [+] character is a special type of content. All characters directly after the [+] character are seen by STF as a
filename. STF opens the file and includes the complete content in the output. All the [<] and [>] characters are
replaced with their html entities, respectively &lt; and &gt;

Also all [<] and [>] characters in lines which belong to a code paragraph are replaced with their html entities.

All content types have default html tags bind to them:

        CONTENT TYPE            DEFAULT HTML TAG
        document title          <h1></h1>
        sub title               <h2></h2>
        text paragraph          <p></p>
        code paragraph          <pre></pre>
        list items              <ul><li></ul>
        include file            <i><pre></pre></i>

However all html tags can be customized. Create a STF configuration file with the name 'stf.conf' in the
/etc/ directory. The format of the configuration file looks like this:

        IDENTIFIER=HTMLTAG

Identifiers are:

        sd=Start document title
        ed=End document title
        ss=Start sub title
        es=End sub title
        st=Start text paragraph
        et=End text paragraph
        sc=Start code paragraph
        ec=End code paragraph
        sl=Start list
        el=End list
        sb=List item
        si=Start include file
        ei=End include file
        sa=Start anchor TOC
        ea=End anchor TOC
        sn=TOC title
        so=Start TOC
        eo=End TOC
        sv=Version information

Note that maximal number of characters for a html tag is restricted to 256 and that no spaces may occur between
the identifier, the = character and the value.

.SH OPTIONS
.TP
\fB-h headerfile\fP
Include <headerfile> in the top of the output.
.TP
\fB-f footerfile\fP
Include <footerfile> at the bottom of the output.
.TP
\fB-i\fP
Include table of contents based on subtitles
.TP
\fB-t\fP
Include timestamp after stf output before footer file
.TP
\fB-u\fP
Convert doc- & subtitles to uppercase
.TP
\fB-l\fP
Convert doc- & subtitles to lowercase
.TP
\fB-v\fP
Display version information and exit
\fB--help\fP
Display extended help information and exit

.SH FILES
Stf searches for a file called stf.conf in the /etc/ directory and will parse the text file according to the values specified.
.SH BUGS
Probably a lot but if you stick to the rules you should be fine :)
.SH AUTHOR
Fred Wijnsma <wijnsma@yahoo.com>
.SH LICENSE
Stf is publiced under the GPL license.
.SH VERSION
Stf version 1.0.1 (c) 2000 QaD
